# Mistyfy change log

**Release 2.0.4** - 2022-04-16
### Patch
* Patches

**Release 2.0.3** - 2022-04-16
### Patch
* Minor patch updates
* Documentation update


**Release 2.0.2** - 2022-04-11
### Patch
* Minor patch updates


**Release 2.0.1** - 2022-04-11
### Patch
* Minor patch updates


**Release 2.0.0** - 2022-04-11
### Major
* Modified the entire module
* Added readthedocs page
* Renamed `algo.py` file to `misty.py` file
* Made the output from `encode` and `decode` function to be strings. This way, the result can be
easily stored into a database table.
* Added a key word argument to `encode` function called `expire` - which helps with adding a timestamp to 
invalidate the decoding function.
  

**Release 1.0.1** - 2021-08-21
### Patch
* Corrected minor sentence.

**Release 1.0.0** - 2021-08-16
### Encryption in your own hands 👍
* Mistyfy is a simple algorithm that incorporates other known or popular encryption standards such as base64 and blake2b.
* Mistyfy creates a unique ciphers using number and interchanges ascii characters to a specific number.
* You can be able to use your own unique cipher or create a new cipher using dictionaries for each characters.